pub struct RunOptions {
pub dry_run: bool,
pub continue_on_error: bool,
}Expand description
Options for bootstrap execution.
Fields
dry_run: boolIf true, verify all steps and report status without making changes.
continue_on_error: boolIf true, continue running even if a required step fails verification.